@@ -9,10 +9,15 @@ def output(value, sep='-----'):
     :param sep: 分隔符
     :return:
     """
+    # if sep == '\n':
+    #     print(f'表达式：{repr(value)} {sep}类型：{type(value)} {sep}值：{value}')
+    # else:
+    #     print(f'表达式：{repr(value)} {sep} 类型：{type(value)} {sep} 值：{value}')
+
     if sep == '\n':
-        print(f'表达式：{repr(value)} {sep}类型：{type(value)} {sep}值：{value}')
+        print(f'类型：{type(value)} {sep}值：{value}')
     else:
-        print(f'表达式：{repr(value)} {sep} 类型：{type(value)} {sep} 值：{value}')
+        print(f'类型：{type(value)} {sep} 值：{value}')
 
 
 def create_dir(dir_path):
